@@ -44,7 +44,7 @@
 static void version() {
     fprintf(stdout, "bzip3 " VERSION
                     "\n"
-                    "Copyright (C) by Kamila Szewczyk, 2022-2023.\n"
+                    "Copyright (C) by Kamila Szewczyk, 2022-2025.\n"
                     "License: GNU Lesser GPL version 3 <https://www.gnu.org/licenses/lgpl-3.0.en.html>\n");
 }
 
@@ -71,7 +71,7 @@ static void help() {
             "  -j N, --jobs=N    set the amount of parallel threads\n"
 #endif
             "\n"
-            "Report bugs to: https://github.com/kspalaiologos/bzip3\n");
+            "Report bugs to: https://github.com/iczelia/bzip3\n");
 }
 
 static void xwrite(const void * data, size_t size, size_t len, FILE * des) {
@@ -650,6 +650,10 @@ int main(int argc, char * argv[]) {
                         output_name = NULL;
                     else {
                         output_name = malloc(strlen(arg) + 5);
+                        if (!output_name) {
+                            fprintf(stderr, "Failed to allocate memory.\n");
+                            return 1;
+                        }
                         strcpy(output_name, arg);
                         strcat(output_name, ".bz3");
                     }
@@ -677,6 +681,10 @@ int main(int argc, char * argv[]) {
                         output_name = NULL;
                     else {
                         output_name = malloc(strlen(arg) + 1);
+                        if (!output_name) {
+                            fprintf(stderr, "Failed to allocate memory.\n");
+                            return 1;
+                        }
                         strcpy(output_name, arg);
                         if (strlen(output_name) > 4 && !strcmp(output_name + strlen(output_name) - 4, ".bz3"))
                             output_name[strlen(output_name) - 4] = 0;
@@ -744,6 +752,10 @@ int main(int argc, char * argv[]) {
                     output = NULL;
                 else {
                     output = malloc(strlen(f1) + 5);
+                    if (!output) {
+                        fprintf(stderr, "Failed to allocate memory.\n");
+                        return 1;
+                    }
                     strcpy(output, f1);
                     strcat(output, ".bz3");
                 }
@@ -760,6 +772,10 @@ int main(int argc, char * argv[]) {
                     output = NULL;
                 else {
                     output = malloc(strlen(f1) + 1);
+                    if (!output) {
+                        fprintf(stderr, "Failed to allocate memory.\n");
+                        return 1;
+                    }
                     strcpy(output, f1);
                     if (strlen(output) > 4 && !strcmp(output + strlen(output) - 4, ".bz3"))
                         output[strlen(output) - 4] = 0;
@@ -795,4 +811,4 @@ int main(int argc, char * argv[]) {
         remove_in_file(input, output_des);
     }
     return r;
-}
\ No newline at end of file
+}
